%Check stopping criterion : checks if the stopping criterion is satisfied
%at a given iteration
%%
%% [stopstatus,printstatus,statusstr,runhist] = TEBD_Check_StopCrit(par,residuals,runhist,iter,stopstatus)
%%
%% input:
%%		- par                : (struct) parameters of the algorithm
%%		- resduals           : (struct) contains the specific residuals of the problem at the current iteration 
%%		- runhist            : (struct) contains the accumulated running history
%%		- iter               : current  iteration
%%		- stopstatus         : flag that defines which stopping criteria are going to be considered 
%%		
%% output:
%%		- stopstatus         : flag that defines which stopping criteria are going to be considered 
%%		- printstatus        : is 1 if a stopping criterion is satisfied 0 otherwise 
%%		- statusstr          : if printstatus = 1 a string of the stopping 
%%                             criterion status at the current iterations (iter) 
%%		- runhist            : (struct) contains the accumulated running 
%%                             history, including the final norm of the 
%%                             residuals and the number of the iterations 
%%                             of the stopping criterion satisfied.
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 6/15/2012
function   [stopstatus,printstatus,statusstr,runhist] = TEBD_Check_StopCrit(par,residuals,runhist,iter,stopstatus)
statusstr = '';
printstatus = 0;
if stopstatus >= 3 && residuals.resnorm3 < par.tol
    statusstr = [statusstr ,'****************Stop Criterion 3 satisfied**************************\n'];
    stopstatus = 2;
    printstatus = 1;
    runhist.finalresnorm3 = residuals.resnorm3;
    runhist.numiterations3 = iter;
end
if stopstatus >= 2 && residuals.resnorm2 < par.tol
    statusstr = [statusstr ,'****************Stop Criterion 2 satisfied**************************\n'];
    stopstatus = 1;
    printstatus = 1;
    runhist.finalresnorm2 = residuals.resnorm2;
    runhist.numiterations2 = iter;
end
if stopstatus >= 1 && residuals.resnorm < par.tol
    statusstr = [statusstr ,'****************Stop Criterion satisfied**************************\n'];
    stopstatus = 0;
    printstatus = 0;
end


    