% Save final values: save the info after running 2EBD-HPE
%%
%% results = results = TEBD_GetFinalValues_1(runhist,iter,par,prob,x,u,u_tilde,x_tilde,y_tilde,Z_tilde,residuals_d,secs)
%%
%% input:
%%		- obj                : contains the values of the objective function(s)
%%		- runhist            : (struct) contains the accumulated running history
%%		- iter               : current  iteration
%%		- par                : (struct) parameters of the algorithm
%%		- prob               : (struct) problem definition
%%      - x                  : the current point x (1st block variable)
%%      - u                  : the current point u (2nd block variable)
%%      - u_tilde            : the current itermediate point u_tilde (2nd block variable)
%%      - x_tilde            : the current itermediate point x_tilde (1st block variable)
%%      - Z_tilde            : (struct) the current dual variable Z_tilde (1st block dual variable)
%%      - y_tilde            : (struct) the current dual variable y_tilde (2nd block dual variable)
%%      - residuals_d        : (struct) the current residuals (primal-dual feasibilities and duality gap) obtained directly from the dual variables
%%		- secs               : time at the current iteration
%%		
%% output:
%%		- results                       : (struct) contains all the results after running 2EBD
%%		- results.x                     : resulting point x (1st block variable)  measured for convergence (x_tilde) at the las iteration
%%		- results.u                     : resulting point u (2nd block variable)  measured for convergence (u_tilde) at the las iteration
%%		- results.obj                   : objective function(s) at the last iteration
%%		- results.par                   : (struct) parameters of the algorithm
%%		- results.prob                  : (struct) problem definition
%%		- results.finalresiduals        : (struct) the residuals (primal-dual feasibilities and duality gap) obtained at the last iteration
%%		- results.runhist.x_tilde       : itermediate point u_tilde (2nd block variable) at the last iteration
%%		- results.runhist.obj           : accumulated running history of the objective function(s)
%%		- results.runhist               : (struct) contains the accumulated running history, including the info from the current iteration (iter)
%%		- results.runhist.x             : point x (1st block variable) at the las iteration
%%		- results.runhist.u             : point u (2nd block variable) at the las iteration
%%		- results.runhist.Z             : (struct) dual variable Z (1st block dual variable) at the last iteration
%%		- results.runhist.y             : (struct) dual variable Z (2nd block dual variable) at the last iteration
%%		- results.runhist.finalobj      : objective function(s) at the last iteration
%%		- results.runhist.x_tilde       : itermediate point x_tilde (1st block variable) at the last iteration
%%		- results.runhist.u_tilde       : itermediate point u_tilde (2nd block variable) at the last iteration
%%		- results.runhist.Z_tilde       : (struct) dual variable Z_tilde (1st block dual variable) at the last iteration
%%		- results.runhist.y_tilde       : (struct) dual variable y_tilde (2nd block dual variable) at the last iteration
%%		- results.runhist.processtime   : total running time of the method without including preprocessing time 
%%		- results.runhist.numiterations : total number of iterations taken
%%		- results.runhist.eachiteration : average time per itertion of the method
%%		- results.runhist.totaltime     : total running time of the method including preprocessing time
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013
function results = TEBD_GetFinalValues_1(runhist,iter,par,prob,x,u,u_tilde,x_tilde,y_tilde,Z_tilde,secs)
runhist.maxitreached = 0;
if (iter>=par.maxit);
    fprintf('max iterations reached. \n');
    runhist.maxitreached = 1;
end
obj = runhist.obj{iter};

runhist.x = x;
runhist.u = u;
runhist.finalobj = obj;
runhist.u_tilde = u_tilde;
runhist.x_tilde = x_tilde;


runhist.processtime = secs;
runhist.numiterations = iter;
runhist.eachiteration = secs/iter;
runhist.totaltime = secs+runhist.preprocesstime;

if ~isfield(runhist,'finalresnorm2'); runhist.finalresnorm2 = runhist.finalbestresnorm; end;
if ~isfield(runhist,'numiterations2'); runhist.numiterations2 = runhist.numiterations; end;
if ~isfield(runhist,'finalresnorm3'); runhist.finalresnorm3 = runhist.finalresnorm2; end;
if ~isfield(runhist,'numiterations3'); runhist.numiterations3 = runhist.numiterations2; end;

results.runhist = runhist;
results.x = x_tilde;
results.u = u_tilde;
results.y = y_tilde;
results.Z = Z_tilde;
results.obj = obj;
results.par = par;
results.prob = prob;

residuals_d = runhist.residual(iter);
results.finalresiduals = residuals_d;


fprintf('preprocess time: %10.3f \n',runhist.preprocesstime);
fprintf('# iterations: %d \n',runhist.numiterations);
fprintf('iterations time: %10.3f \n',runhist.processtime);
fprintf('each iteration time: %f \n',runhist.eachiteration);
fprintf('Final norm of residual: %e \n',runhist.finalbestresnorm);
fprintf('pfeas=%8.3e, dfeas=%8.3e, gap=%8.3e \n', residuals_d.pfeas,residuals_d.dfeas,residuals_d.gap);
fprintf('total time: %10.3f \n',runhist.totaltime);
end
