%Save history: Save the progress at the current iteration
%%
%% runhist = TEBD_SaveHistory(obj,runhist,iter,residuals,secs,lambda_ratio,theta)
%%
%% input:
%%		- obj                : contains the values of the objective function(s)
%%		- runhist            : (struct) contains the accumulated running history
%%		- iter               : current  iteration
%%		- resduals           : (struct) contains the specific residuals of the problem at the current iteration 
%%		- secs               : time at the current iteration
%%		- lambda_ratio       : ratio between a the adaptive and the non-adaptive stepsizes (lambda)
%%		- theta              : value of the dynamic scaling parameter at the current iteration
%%		
%% output:
%%		- runhist                   : (struct) contains the accumulated running history, including the info from the current iteration (iter)
%%		- runhist.obj               : accumulated running history of the objective function(s)
%%		- runhist.theta             : accumulated running history of the dynamic scaling parameter
%%		- runhist.gap               : accumulated running history of the duality gap (if it applies for the given problem)
%%		- runhist.resnorm           : accumulated running history of the problem specific norms of the residuals 
%%		- runhist.lambda_ratio      : accumulated running history of the ratio between a the adaptive and the non-adaptive stepsizes (lambda)
%%		- runhist.residual          : accumulated running history of the specific residuals of the problem at the current iteration 
%%		- runhist.cputime           : accumulated running history of the time at every iteration
%%		- runhist.finalbestresnorm  : the current minimum norm of the residuals
%%		- runhist.objbest           : the objective function(s) at the iteration with minimum norm of the residuals
%%		- runhist.bestiteration     : the iteration with minimum norm of the residuals
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 6/15/2012
function runhist = TEBD_SaveHistory(obj,runhist,iter,residuals,secs,lambda_ratio,theta)

runhist.obj{iter}= obj;

runhist.theta(iter)= theta;

runhist.gap(iter)= residuals.gap;

runhist.resnorm(iter) = residuals.resnorm;

runhist.lambda_ratio(iter) = lambda_ratio;

runhist.residual(iter) = residuals;

runhist.cputime(iter) = secs;

if iter == 1 || runhist.finalbestresnorm >= residuals.resnorm
    runhist.finalbestresnorm = residuals.resnorm;
    runhist.objbest(1)=runhist.obj(iter);
    runhist.bestiteration = iter;
end


