%Basic Operations: Perform various basic operations for block structured elements
%%******************************************************************
%% ops:
%%
%%   [Z,Z2,Z3] = TEBD_ops(X,operand,Y,alpha);
%%
%%  INPUT:        X = a matrix or a scalar
%%                    or a CELL ARRAY consisting only of matrices
%%          operand = sym, transpose, triu, tril,
%%                    real, imag, sqrt, abs, max, min, nnz,
%%                    spdiags, ones, norm, sum, row-norm,
%%                    rank1, rank1inv, inv
%%                    +,  -, *, .*,  ./, .^
%%     Y (optional) = a matrix or a scalar
%%                    or a CELL ARRAY consisting only of matrices
%%  alpha(optional) = a matrix or a scalar
%%                    or a CELL ARRAY consisting only of matrices
%%    X2 (optional) = a matrix or a scalar
%%                    or a CELL ARRAY consisting only of matrices
%%    Y2 (optional) = a matrix or a scalar
%%                    or a CELL ARRAY consisting only of matrices
%% alpha2(optional) = a matrix or a scalar
%%                    or a CELL ARRAY consisting only of matrices
%%    X3 (optional) = a matrix or a scalar
%%                    or a CELL ARRAY consisting only of matrices
%%    Y3 (optional) = a matrix or a scalar
%%                    or a CELL ARRAY consisting only of matrices
%%***********************************************************
%% DSA_BD:
%% Modified by C.Ortiz 3/31/2011
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 6/15/2012

function [Z,Z2,Z3] = TEBD_ops(X,operand,Y,alpha,X2,Y2,alpha2,X3,Y3)


if (nargin == 2)
    if strcmp(operand,'norm');
        if ~iscell(X);
            Z = full(norm(X,'fro'));%full(sqrt(sum(sum(X.*X))));
        else
            Z = 0;
            for p = 1:length(X); Z = Z + norm(X{p},'fro')^2;end;%sum(sum(X{p}.*X{p})); end;
            Z = sqrt(Z);
        end
        
    elseif strcmp(operand,'zeros')
        if ~iscell(X)
            Z = zeros(size(X,1),size(X,2));
        else
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = zeros(size(X{p},1),size(X{p},2));
            end
        end
    
        
    elseif strcmp(operand,'eye')
        if ~iscell(X)
            Z = eye(size(X,1),size(X,2));
        else
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = eye(size(X{p},1),size(X{p},2));
            end
        end
    elseif strcmp(operand,'ones')
        if ~iscell(X)
            Z = ones(size(X,1),size(X,2));
        else
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = ones(size(X{p},1),size(X{p},2));
            end
        end
    end
elseif (nargin == 3)
    if strcmp(operand,'+') || strcmp(operand,'-') || ...
            strcmp(operand,'/') || strcmp(operand,'./') || ...
            strcmp(operand,'*') || strcmp(operand,'.*') || ...
            strcmp(operand,'.^')
        if (~iscell(X) && ~iscell(Y))
            eval(['Z = X',operand,'Y;']);
        elseif (iscell(X) && iscell(Y))
            Z = cell(size(X));
            for p = 1:length(X)
                if (size(X{p},2) == 1) && (size(Y{p},2) == 1) && ...
                        (strcmp(operand,'*') || strcmp(operand,'/'))
                    eval(['Z{p} = X{p}.',operand,'Y{p};']);
                else
                    eval(['Z{p} = X{p} ',operand,'Y{p};']);
                end;
            end;
        elseif (iscell(X) && ~iscell(Y))
            Z = cell(size(X));
            for p = 1:length(X);
                eval(['Z{p} = X{p}',operand,'Y;']);
            end
        elseif (~iscell(X) && iscell(Y))
            Z = cell(size(Y));
            for p = 1:length(Y);
                eval(['Z{p} = X',operand,'Y{p};']);
            end
        end
    elseif strcmp(operand,'diffnorm')
        if ~iscell(X);
            Z = full(norm(X-Y,'fro'));%full(sqrt(sum(sum(X.*X))));
        else
            Z = 0;
            for p = 1:length(X); Z = Z + norm(X{p}-Y{p},'fro')^2;end;%sum(sum(X{p}.*X{p})); end;
            Z = sqrt(Z);
        end
    else
        error([operand,' is not available, check input arguments']);
    end
elseif (nargin == 4)
    if strcmp(operand,'+') || strcmp(operand,'-')
        if ~iscell(X) && ~iscell(Y)
            eval(['Z = X',operand,'alpha*Y;']);
        elseif (iscell(X) && iscell(Y))
            Z = cell(size(X));
            for p = 1:length(X)
                if (~iscell(X{p}) )
                    eval(['Z{p} = X{p}',operand,'alpha*Y{p};']);
                else
                    Z{p} = TEBD_ops(X{p},operand,Y{p},alpha);
                end
            end
        else
            error('X, Y are different objects');
        end
    elseif strcmp(operand,'calc2')
        if (~iscell(X) )
            Z = -X+Y+alpha;
        else 
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = -X{p}+Y{p}+alpha{p};
            end;
        end
        
    elseif strcmp(operand,'(X-Y)/alpha')
        if (~iscell(X) )
            Z = (X-Y)/alpha;
        else 
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = (X{p}-Y{p})/alpha;
            end;
        end
    elseif strcmp(operand,'(X+Y*alpha)/alpha')
        if (~iscell(X) )
            Z2 = (X+Y*alpha);
            Z = Z2/alpha;
        else
            Z = cell(size(X));
            Z2 = cell(size(X));
            for p = 1:length(X)
                Z2{p} = (X{p}+Y{p}*alpha);
                Z{p} = Z2{p}/alpha;
            end;
        end
    elseif strcmp(operand,'X-Y-alpha')
        if (~iscell(X) )
            Z = (X-Y-alpha);
        else
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = (X{p}-Y{p}-alpha{p});
            end;
        end
    else 
        error([operand,' is not available']);
    end
elseif (nargin == 5)
    if strcmp(operand,'calc3')
       if (~iscell(X) )
            Z = X-((Y-X2)*alpha);
        else 
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = X{p}-((Y{p}-X2{p})*alpha);
            end;
        end 
    
    elseif strcmp(operand,'calc5')
       if (~iscell(X) )
            Z = X-((Y-X2)*alpha);
        else 
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = X{p}-((Y{p}-X2{p})*alpha);
            end;
        end 

    elseif strcmp(operand,'calc7')
       if (~iscell(X) )
            Z = (1-Y/alpha)*X+(Y/alpha)*X2;
        else 
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = (1-Y/alpha)*X{p}+(Y/alpha)*X2{p};
            end;
        end 

    elseif strcmp(operand,'X-alpha*(Y+X2)')
       if (~iscell(X) )
            Z = X-alpha*(Y+X2);
        else 
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = X{p}-alpha*(Y{p}+X2{p});
            end;
        end 

    elseif strcmp(operand,'(X-Y)/alpha+X2')
       if (~iscell(X) )
            Z = (X-Y)/alpha;
            Z2 = Z+X2;
        else 
            Z = cell(size(X));
            Z2 = cell(size(X));
            for p = 1:length(X)
                Z{p} = (X{p}-Y{p})/alpha;
                Z2{p} = Z{p}+X2{p};
            end;
        end 

    end
    
    
elseif (nargin == 6)
    if strcmp(operand,'calc1')
        if (~iscell(X) )
            Z = (((X-Y)/alpha) + X2-Y2);
        else 
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = (((X{p}-Y{p})/alpha)+X2{p}-Y2{p});
            end;
        end
    elseif strcmp(operand,'calc4')
        if (~iscell(X) )
            Z = (X/Y)+(((X2-Y2)/alpha));
        else 
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = (X{p}/Y)+(((X2{p}-Y2{p})/alpha));
            end;
        end
    elseif strcmp(operand,'(X-Y)/alpha+X2-Y2')
       if (~iscell(X) )
            Z = (X-Y)/alpha+X2;
            Z2 = Z-Y2;
        else 
            Z = cell(size(X));
            Z2 = cell(size(X));
            for p = 1:length(X)
                Z{p} = (X{p}-Y{p})/alpha++X2{p};
                Z2{p} = Z{p}-Y2{p};
            end;
        end 
    end
elseif (nargin == 7)
    if strcmp(operand,'calc6')
        if (~iscell(X) )
            Z = ((X*(1-Y/alpha))+((X2*Y/alpha)-(Y2*alpha2)));
        else
            Z = cell(size(X));
            for p = 1:length(X)
                Z{p} = ((X{p}*(1-Y/alpha))+((X2{p}*Y/alpha)-(Y2{p}*alpha2)));
            end;
        end
    elseif strcmp(operand,'[(X-Y)/alpha]/alpha2-X2-Y2')
        if (~iscell(X) )
            Z = (X-Y)/alpha;
            Z2 = Z/alpha2;
            Z3 = Z2-X2-Y2;
        else
            Z = cell(size(X));
            Z2 = cell(size(X));
            Z3 = cell(size(X));
            for p = 1:length(X)
                Z{p} = (X{p}-Y{p})/alpha;
                Z2{p} = Z{p}/alpha2;
                Z3{p} = Z2{p}-X2{p}-Y2{p};
            end;
        end
    end
elseif (nargin == 9)
    if strcmp(operand,'[(X-Y)/alpha +(X2-Y2)*alpha2]/alpha2-X3-Y3')
       if (~iscell(X) )
            Z = (X-Y)/alpha +(X2-Y2)*alpha2;
            Z2 = Z/alpha2;
            Z3 = Z2-X3-Y3;
        else 
            Z = cell(size(X));
            Z2 = cell(size(X));
            Z3 = cell(size(X));
            for p = 1:length(X)
                Z{p} = (X{p}-Y{p})/alpha +(X2{p}-Y2{p})*alpha2;
                Z2{p} = Z{p}/alpha2;
                Z3{p} = Z2{p}-X3{p}-Y3{p};
            end;
        end 

    end
end
%%******************************************************************
