%Get Binary Integer quadratic Problem (BIQ) two-easy-block structure definition
%%******************************************************************
%% ops:
%%
%%   prob = TEBD_GetBIQ(prob)
%%
%%  INPUT:      prob = (struct) problem definition for obtaining the SDP
%%
%%  OUTPUT:     prob = (struct) problem definition
%%                    
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 6/15/2012
%% 
%% E(i) = 1 if i = (j,j)
%% E(i) = 2 if i = (j,n), j<n
%% E(i) = 3 if i = (n,n)
%% E(i) = 0 o/w
function prob = TEBD_GetBIQ(prob)

n = prob.blk{1,2};
n2 = (n)*(n+1)/2;

%E = sparse(n2,1);
Imat = speye(n);
Imat(n,n) = 3;

SideMat = [sparse(n-1,n-1),ones(n-1,1);sparse(1,n)];
SideMat = SideMat + SideMat';
SideVec = svec({'s' n},SideMat);
SideVec(SideVec~=0) = 2;

prob.E = svec({'s' n},Imat) + SideVec;

prob.E1 = (prob.E == 1);
prob.E2 = (prob.E == 2);
prob.E3 = (prob.E == 3);
prob.E0 = (prob.E == 0);

prob = rmfield(prob,'E');

prob.x0 = zeros(n2,1);
prob.C = svec({'s',n},prob.C);
prob.C = prob.C{1};
 
