%Get Frequency Assignment Problem (FAP) two-easy-block structure definition
%%******************************************************************
%% ops:
%%
%%   prob = TEBD_FAP(prob)
%%
%%  INPUT:      prob = (struct) problem definition of the SDP
%%
%%  OUTPUT:     prob = (struct) problem definition
%%                    
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 6/15/2012
%% 
%% E(i) = 1 if i = (j,j)
%% E(i) = 2 if i \in E\U
%% E(i) = 3 if i \in U
%% E(i) = 0 o/w
function prob = TEBD_GetFAP(prob)

n = prob.blk{1,2};
n2 = n*(n+1)/2;


Ivec = svec({'s',prob.n},speye(n));

EU_indices = sum(prob.At{2},1)~=0;

E = sum(prob.At{1}(:,EU_indices),2);
E(E~=0) = 2*E(E~=0)./E(E~=0);

U_indices = find(sum(prob.At{2},1)==0);
U_indices = U_indices(prob.n+1:end);
U = sum(prob.At{1}(:,U_indices),2);
U(U~=0) = 3*U(U~=0)./U(U~=0);
prob.E = Ivec + E + U;
if nnz(prob.E) ~= size(prob.b,1)
    error('Inconsistent number of nnz in the mask E');
end

prob.E0 = (prob.E == 0);
prob.E1 = (prob.E == 1);
prob.E2 = (prob.E == 2);
prob.E3 = (prob.E == 3);


prob.x0 = sparse(n2,1);
prob.C = svec({'s',prob.n},prob.C);
prob.C = prob.C{1};

prob = rmfield(prob,'E');

