%%***************************************************************************
%% project: compute X = projx-projZ/lambda, where projx, projZ are positive semidefinite.
%%
%% [projx,projZ] = TEBD_GetMatProjectionToGeneralCone_v2_2(blk,X,Z,lambda);
%%
%% SDPNAL:
%% Copyright (c) 2008 by
%% Xinyuan Zhao, Defeng Sun, and Kim-Chuan Toh
%%***************************************************************************
%% DSA_BD:
%% Modified by C.Ortiz
%% Last Modified: 3/31/2011
%%***************************************************************************
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013

function [projx,projZ] = TEBD_GetMatProjectionToGeneralCone_v2_2(blk,X,Z,lambda)

tol = 1e-12; %% must be small as it will affect gap
if ~iscell(X);
    if strcmp(blk{1},'s');
        blktmp = blk{1,2};
        n = sum(blktmp);
        if (length(blktmp) > 1);
            projx = sparse(n,n);
            projZ.Z = sparse(n,n);
            projZ.nev = 0;
            s  = [0, cumsum(blktmp)];
            for i = 1:length(blktmp)
                pos = [s(i)+1 : s(i+1)];
                [Xpsub,Xnsub] = TEBD_GetMatProjectionToSemidefiniteCone_v2_2(n,full(X(pos,pos)),Z,lambda);
                projx(pos,pos) = sparse(Xpsub);
                projZ.Z(pos,pos) = sparse(Xnsub.Z);
                projZ.nev =  projZ.nev+Xnsub.nev;
            end
        else
            [projx,projZ] = TEBD_GetMatProjectionToSemidefiniteCone_v2_2(n,X,Z,lambda);
        end
    elseif strcmp(blk{1},'l');
        n = sum(blk{1,2});
        projx = zeros(n,1); posidx = (X > tol);
        projZ.nev = sum(posidx);
        if ~isempty(posidx)
            projx(posidx) = abs(X(posidx)); projZ.Z = abs(projx-X);
        else
            projZ.Z = abs(X);
        end
        projZ.Z = projZ.Z/lambda;
        %% C. Oritz>>
    elseif strcmp(blk{1},'u');
        projx = X;
        projZ.Z = 0;
        projZ.nev = blk{2};
        %% C. Ortiz<<
    end
else
    projx = cell(size(X)); projZ.Z = cell(size(X)); projZ.nev = 0;
    for p = 1:size(blk,1)
        [projx{p},projZtmp] = TEBD_GetMatProjectionToGeneralCone_v2_2(blk(p,:),X{p},Z,lambda);
        projZ.Z{p} = projZtmp.Z;
        projZ.nev = projZ.nev + projZtmp.nev;
    end
end
%%***************************************************************************
