%Project matrix onto the positive semidefinite cone.
%The matrix is reconstructed using the diagonal with least non-zeros
%(positive or negative eigenvalues).
%%******************************************************************
%% ops: 
%%
%%   projx = TEBD_GetProjectionToSemidefiniteCone_Simplex_v2_2(prob,x)
%%
%%  INPUT:     prob = problem definition
%%                x = vectorized matrix
%%  OUTPUT:   projx = projection of x on to the intersection of the
%%                    semidefinite cone and the unit simplex
%%                Z = (struct) the dual variables corresponding to
%%                    the optimization problem form the projection
%%              Z.Z = the dual variable corresponding to the 
%%                    constraint of x in the PSD cone.
%%***********************************************************
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013
function [projx,Z] = TEBD_GetMatProjectionToSemidefiniteCone_v2_2(n,x,Z,lambda)
 
EPS = 1e-12;
[V,D] = mexeig(full(x));
D = diag(D);
nD = D>EPS;   
Z.nev = nnz(nD);
if Z.nev == 0
    Z.pos = 1;
    projx = zeros(size(x));
    Z.Z = (-1/lambda)*x;
elseif Z.nev == n
    Z.nev = 0;
    Z.Z = zeros(size(x));
    projx = x;  
elseif Z.nev <= n/2
    Z.pos = 1;
    projx = (V(:,nD)*diag(D(nD))*V(:,nD)');
    Z.Z = (projx-x)/lambda;
else
    nD = D<-EPS;
    Z.nev = nnz(nD);
    Z.Z = (V(:,nD)*diag(-D(nD))*V(:,nD)');
    projx = x+Z.Z;  
    Z.Z = Z.Z/lambda;
end
end
