%Project a point onto the second block of constraints of the FAP
%which consist on all but the constraint corresponding to the PSD cone
%%******************************************************************
%% ops:
%%
%%   [proju,y] = TEBD_GetProjectionToK_FAP_v2(prob,u,lambda)
%%
%%  INPUT:      prob   = (struct) problem definition
%%              u      = point to project
%%              lambda = scalar from the resolvent
%%
%%  OUTPUT:     proju  = the projection of the point u
%%              y      = (struct) (optinal) the corresponging dual 
%%                       variable from the projection opt. problem
%%              y.y    = the dual variable
%%              y.Aty  = the solution to A'*y where A is the matrix 
%%                       corresponding to the second block of constraints
%%                    
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013

function [proju,y] = TEBD_GetProjectionToK_FAP_v2(prob,u,lambda)
proju = u;
proju(prob.E1) = 1;
proju(prob.E2) = max(-sqrt(2)/(prob.k-1),proju(prob.E2));
proju(prob.E3) = sqrt(2)*(-1/(prob.k-1));

if  nargout > 1
    y.y = zeros(size(u,1),1);
    y.Aty = zeros(size(u,1),1);
    
    y.y(prob.E1) = lambda*(1-u(prob.E1));
    y.y(prob.E2) = (-lambda)*min(u(prob.E2)+sqrt(2)/(prob.k-1),0);
    y.y(prob.E3) = lambda*(u(prob.E3)+sqrt(2)/(prob.k-1));
    
    y.Aty(prob.E1) =  y.y(prob.E1);
    y.Aty(prob.E2) = y.y(prob.E2);
    y.Aty(prob.E3) = -y.y(prob.E3);
end

end
