%Project a point onto the second block of constraints of the THETAPLUS problem
%which consist on all but the constraint corresponding to the PSD cone
%%******************************************************************
%% ops:
%%
%%   [proju,y] = TEBD_GetProjectionToK_THETAPLUS_v2(prob,u,lambda)
%%
%%  INPUT:      prob   = (struct) problem definition
%%              u      = point to project
%%              lambda = scalar from the resolvent
%%
%%  OUTPUT:     proju  = the projection of the point u
%%              y      = (struct) (optinal) the corresponging dual 
%%                       variables from the projection opt. problem
%%              y.y    = the dual variable corresponding to the equality
%%                       constraints
%%              y.S    = the dual variable corresponding to x>=0
%%              y.Aty  = the solution of A'*y where A is the matrix 
%%                       corresponding to the equality constraints
%%                    
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013

function [proju,y] = TEBD_GetProjectionToK_THETAPLUS_v2(prob,u,lambda)
proju = zeros(size(u,1),1);
[proju(prob.E1),tmax] = TEBD_projsplx(u(prob.E1));
idxpos = prob.E0&u>0;
proju(idxpos) = u(idxpos);

if  nargout > 1
    idxneg = prob.E0&u<0;
    y.y = zeros(prob.m,1);
    y.S = zeros(size(u,1),1);
    y.Aty = zeros(size(u,1),1);
    
    y.y(1:prob.m-1) = (-lambda)*u(prob.E2);
    y.y(prob.m) = -lambda*tmax;
    
    y.S(prob.E1) = lambda*(proju(prob.E1)-u(prob.E1)+tmax);
    y.S(idxneg) = (-lambda)*u(idxneg);
    
    y.Aty(prob.E1) = y.y(prob.m);
    y.Aty(prob.E2) = y.y(1:prob.m-1);
end
end
