%Project a point onto the second block of constraints of the THETA problem
%which consist on all but the constraint corresponding to the PSD cone
%%******************************************************************
%% ops:
%%
%%   [proju,y] = TEBD_GetProjectionToK_THETA_v2(prob,u,lambda)
%%
%%  INPUT:      prob   = (struct) problem definition
%%              u      = point to project
%%              lambda = scalar from the resolvent
%%
%%  OUTPUT:     proju  = the projection of the point u
%%              y      = (struct) (optinal) the corresponging dual 
%%                       variables from the projection opt. problem
%%              y.y    = the dual variable corresponding to the equality
%%                       constraints
%%              y.Aty  = the solution of A'*y where A is the matrix 
%%                       corresponding to the equality constraints
%%                    
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013

function [proju,y] = TEBD_GetProjectionToK_THETA_v2(prob,u,lambda)
proju = u;
utmp  = u(prob.E1);
ntmp = size(utmp,1);
etmp = ones(ntmp,1);
vtmp = (1-sum(utmp))/ntmp;
proju(prob.E1) = utmp + vtmp*etmp;
proju(prob.E2) = 0;

if  nargout > 1
    y.y = zeros(prob.m,1);
    y.Aty = zeros(size(u,1),1);
    
    y.y(1:prob.m-1) = (-lambda)*u(prob.E2);
    y.y(prob.m) = lambda*vtmp;
    
    y.Aty(prob.E1) = y.y(prob.m);
    y.Aty(prob.E2) = y.y(1:prob.m-1);
end
end
