%Project a point onto the second block of constraints of the BIQ problem
%which consist on all but the constraint corresponding to the PSD cone
%%******************************************************************
%% ops:
%%
%%   [proju,y] = TEBD_GetProjectionToK_THETAPLUS_v2(prob,u,lambda)
%%
%%  INPUT:      prob   = (struct) problem definition
%%              u      = point to project
%%              lambda = scalar from the resolvent
%%
%%  OUTPUT:     proju  = the projection of the point u
%%              y      = (struct) (optinal) the corresponging dual 
%%                       variables from the projection opt. problem
%%              y.y    = the dual variable corresponding to the second
%%                       block constraints except x>=0
%%                       constraints
%%              y.S    = the dual variable corresponding to x>=0
%%              y.s    = the dual variable corresponding to the redundant
%%                       constraint diag(x)<=1
%%              y.Aty  = the solution of A'*y where A is the matrix 
%%                       corresponding to the the second
%%                       block constraints except x>=0
%%                    
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013

%% with diag(u)<= 1
function [proju,y] = TEBD_GetProjectionToKle1_BIQ_v2(prob,u,lambda) 
proju = zeros(size(u,1),1);
tmpu = (u(prob.E1)+sqrt(2)*u(prob.E2))/3;
tmpup = max(0,tmpu);
proju(prob.E1) = min(tmpup,1); % with diag(u)<= 1
proju(prob.E2) = sqrt(2)*proju(prob.E1);
proju(prob.E3) = 1;
idxpos = prob.E0&u>0;
proju(idxpos) = u(idxpos);

if  nargout > 1
    idxneg = prob.E0&u<0;

    y.y = zeros(prob.n,1);
    y.s = zeros(prob.n-1,1);
    y.S = zeros(size(u,1),1);
    y.Aty = zeros(size(u,1),1);  
    
    y.S(prob.E1) = tmpup - tmpu; % without diag(u)<= 1
    y.S(prob.E2) = sqrt(2)*y.S(prob.E1);
    y.S(idxneg) = -u(idxneg);
    y.S = y.S*lambda;
    
    tmpup = tmpup-proju(prob.E1);
    y.y(1:prob.n-1) = lambda*(tmpu-u(prob.E1)+2*(tmpup));
    y.y(prob.n) = lambda*(1-u(prob.E3));
    
    y.s = 3*lambda*tmpup;
    
    y.Aty(prob.E1) = y.y(1:prob.n-1);
    
    y.Aty(prob.E1) = y.y(1:prob.n-1)-y.s;
    y.Aty(prob.E2) = -y.y(1:prob.n-1)/sqrt(2);
    y.Aty(prob.E3) = y.y(prob.n);
end
end
