%Project vectorized matrix onto the intersection of the positive semidefinite cone and
%the manifold trace(x)=1. 
%%******************************************************************
%% ops:
%%
%%   projx = TEBD_GetProjectionToSemidefiniteCone_Simplex(prob,x)
%%
%%  INPUT:     prob = problem definition
%%                x = vectorized matrix
%%  OUTPUT:   projx = projection of x on to the intersection of the
%%                    semidefinite cone and the unit simplex
%%***********************************************************
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 6/15/2012
function projx = TEBD_GetProjectionToSemidefiniteCone_Simplex(prob,x)
    pblk = prob.blk(1,:);
    xmat = mexsmat(pblk,x);
    projx =  projectSDPSimplex(xmat);
    projx = svec(pblk,projx);
end

function Xp = projectSDPSimplex(X)
tol = 1e-12;
n = length(X);
if (norm(X-X','fro') > 1e-15*norm(X,'fro'))
    fprintf('nonSym');
    X = 0.5*(X+X');
end
if (exist('mexeig','file')==3)
    [V,D] = mexeig(full(X));
else
    [V,D] = eig(full(X));
end
d = full(diag(D));
d = projsplx(d);
posidx = find(d > tol);

if isempty(posidx)
    Xp = sparse(n,n); 
elseif (length(posidx) == n)
    Xp = X; 
else
    dp = abs(d(posidx));
    Vtmp = V(:,posidx)*diag(sqrt(dp));
    Xp = Vtmp*Vtmp'; Xp = 0.5*(Xp+Xp');
end
end


