%Project vectorized matrix onto the intersection of the positive semidefinite cone and
%the manifold trace(x)=1. The matrix is reconstructed using the diagonal with least non-zeros
%(positive or negative eigenvalues).
%%******************************************************************
%% ops:
%%
%%   projx = TEBD_GetProjectionToSemidefiniteCone_Simplex_v2_2(prob,x)
%%
%%  INPUT:     prob = problem definition
%%                x = vectorized matrix
%%  OUTPUT:   projx = projection of x on to the intersection of the
%%                    semidefinite cone and the unit simplex
%%                Z = (struct) the dual variables corresponding to
%%                    the optimization problem form the projection
%%             Z.ZS = the dual variable corresponding to the 
%%                    constraint of x in the PSD cone.
%%          Z.gamma = the dual variable corresponding to the 
%%                    constraint trace(x) = 1                      
%%***********************************************************
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013
function [projx,Z] = TEBD_GetProjectionToSemidefiniteCone_Simplex_v2_2(prob,x,Z,lambda)
pblk = prob.blk(1,:);
xmat = mexsmat(pblk,x);
EPS = 1e-12;

[V,D] = mexeig(full(xmat));
D = diag(D);
[D,tmax] = TEBD_projsplx_2(D);
nD = D>EPS;   Z.nev = nnz(nD);

Z.nev = nnz(nD);
if Z.nev == 0
    Z.pos = 1;
    projx = zeros(size(x));
    Z.Z = (-1/lambda)*x;
    Z.gamma = -tmax/lambda;
    Z.ZS = Z.Z;
    Z.ZS(prob.E1)=Z.ZS(prob.E1)-Z.gamma;
elseif Z.nev == prob.n
    Z.nev = 0;
    Z.ZS = zeros(size(x));
    projx = x;
    projx(prob.E1)=projx(prob.E1)-tmax;
    Z.gamma = -tmax/lambda;
    Z.ZS = Z.Z;
    Z.ZS(prob.E1)=Z.ZS(prob.E1)-Z.gamma;
    Z.gamma = -tmax/lambda;
    Z.ZS = Z.ZS/lambda;
    Z.Z = Z.ZS;
    Z.Z(prob.E1)=Z.ZS(prob.E1)+Z.gamma;
elseif Z.nev <= prob.n/2
    
    projx = (V(:,nD)*diag(D(nD))*V(:,nD)');
    projx = mexsvec(pblk,projx);
    Z.Z = (projx-x)/lambda;
    Z.gamma = -tmax/lambda;
    Z.ZS = Z.Z;
    Z.ZS(prob.E1)=Z.ZS(prob.E1)-Z.gamma;
else
    nD = ~nD;% D<-EPS;
    Z.nev = nnz(nD);
    Z.ZS = (V(:,nD)*diag(-D(nD))*V(:,nD)');
    Z.ZS = mexsvec(pblk,Z.ZS);
    projx = x+Z.ZS;
    projx(prob.E1)=projx(prob.E1)-tmax;
    Z.gamma = -tmax/lambda;
    Z.ZS = Z.ZS/lambda;
    Z.Z = Z.ZS;
    Z.Z(prob.E1)=Z.ZS(prob.E1)+Z.gamma;
end


end



