%Get the residulas for  the dynamic scaling the stopping criterion 
%max{pfeas,dfeas} or max{pfeas,dfeas,gap/10}
%%******************************************************************
%% ops:
%%
%%   residuals = TEBD_GetResiduals(prob,obj,stop_res_1,stop_res_2,dyn_res_1)
%%
%%  INPUT:      prob = (struct) problem definition of the SDP
%%               obj = array with values of objective functions 
%%        stop_res_1 = 1st residual for the stopping criterion
%%        stop_res_2 = 2nd residual for the stopping criterion (also used for dynamic scaling)
%%         dyn_res_1 = 1st residual for the dynamic scaling
%%
%%  OUTPUT:     residuals = (struct) contains all the relevant residuals
%%        residuals.pfeas = scaled 1st residual for the stopping criterion
%%        residuals.dfeas = scaled 2nd residual for the stopping criterion
%%          residuals.gap = scaled duality gap for the stopping criterion
%%         residuals.res1 = 1st residual for the dynamic scaling
%%         residuals.res2 = 2nd residual for the dynamic scaling
%%     residuals.resnorm2 = max(residuals.pfeas,residuals.dfeas) 
%%                          used when we aim for two stopping criteria. 
%%      residuals.resnorm = max(residuals.pfeas,max(residuals.dfeas,abs(residuals.gap))) or
%%                          max(residuals.pfeas,residuals.dfeas)
%%                          depending on if the gap is included in the sttoping criterion or not.
%%
%%                          residuals.resnorm2<=residuals.resnorm should be satisfied.
%%                    
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013
function residuals = TEBD_GetResiduals_GAP5(prob,obj,stop_res_1,stop_res_2,dyn_res_1)


stop_res_1_scaled = stop_res_1/(prob.normb+1);%F_u;
stop_res_2_scaled = stop_res_2/(prob.normC+1);


residuals.pfeas = dyn_res_1/(prob.normb+1);%F_u;
residuals.dfeas = stop_res_2/(prob.normC2+1);% 

gapnorm = (abs(obj(1))+abs(obj(2))+1);

residuals.gap = (obj(1)-obj(2))/gapnorm;

if prob.scalewithgap == 0
    residuals.res1 = residuals.pfeas; 
    residuals.res2 = residuals.dfeas;
else   
    residuals.res1 = max(residuals.pfeas,dyn_res_1/gapnorm);
    residuals.res2 = max(residuals.dfeas,stop_res_2/gapnorm); 
end

residuals.pfeas = stop_res_1_scaled;
residuals.dfeas = stop_res_2_scaled;

if prob.reswithgap == 1
    residuals.resnorm2 = max(residuals.pfeas,residuals.dfeas);
    residuals.resnorm = max(residuals.pfeas,max(residuals.dfeas,abs(residuals.gap)/10));
else
    residuals.resnorm2 = max(residuals.pfeas,residuals.dfeas);
    residuals.resnorm = max(residuals.pfeas,residuals.dfeas);
end