%Get \theta-function SDP relaxation for the maximum stable set problem  
%using the two-easy-block structure definition
%%******************************************************************
%% ops:
%%
%%   prob = TEBD_GetTHETA(prob)
%%
%%  INPUT:      prob = (struct) problem definition of the SDP
%%
%%  OUTPUT:     prob = (struct) problem definition
%%                    
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 6/15/2012
%% 
%% Given a graph G=(V,A)
%% E(i) = 1 if i = (j,j)
%% E(i) = 2 if i \in A
%% E(i) = 0 o/w
function prob = TEBD_GetTHETA(prob)

n = prob.blk{1,2};
n2 = n*(n+1)/2;

%E = sparse(n2,1);
E = sum(prob.At{1}(:,2:end),2);
Ivec = svec(prob.blk,speye(n));
E(E~=0) = 2;
prob.E = E + Ivec;
prob.x0 = sparse(n2,1);
prob.C = svec({'s',n},prob.C);
prob.C = prob.C{1};

prob.E1 = (prob.E == 1);
prob.E2 = (prob.E == 2);
prob.E0 = (prob.E == 0);

prob = rmfield(prob,'E');
