%Get Standard form SDP from specific instance class file
%%******************************************************************
%% ops:
%%
%%   problem = TEBD_Get_SDP(problem)
%%
%%  INPUT/OUTPUT:     problem = (struct) problem definition
%%
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 6/15/2012
function problem = TEBD_Get_SDP(problem)
disp(['**** From ',problem.format,' file : ',problem.file, '****'])
switch problem.format
    case 'BIQ'
        problem = TEBD_GetBIQ_SDP(problem);
    case 'FAP'
        problem = TEBD_GetFAP_SDP(problem);
    case 'THETA'
        problem = TEBD_GetTHETA_SDP(problem);
    case 'THETAPLUS'
        problem = TEBD_GetTHETA_SDP(problem);
        [problem.blk,problem.At,problem.C,problem.b] = addpositive(problem.blk,problem.At,problem.C,problem.b);
    case 'QAP'
        problem = TEBD_GetQAP_SDP(problem);
    case 'RAND'
        numbs = textscan(problem.file,'%d',4);
        problem.n = double(numbs{1}(1));
        problem.m = double(numbs{1}(2));
        problem.p = double(numbs{1}(3));
        problem.seed = double(numbs{1}(4));
        problem = TEBD_GetRAND_SDP(problem);
    case 'SeDuMi'
        [problem.blk,problem.At,problem.C,problem.b] = read_sedumi(problem.file);
    case 'SDPA'
        [problem.blk,problem.At,problem.C,problem.b] = read_sdpa(problem.file);
    case 'SDPT3'
        problem = load(problem.file);
    otherwise    
        error(['Format "',problem.format,'" is not available, check input arguments']);
end

problem.n = size(problem.C{1},1);
problem.m = length(problem.b);
problem.X0 = TEBD_ops(problem.C,'zeros');


problem.normb = norm(problem.b);
problem.normC = TEBD_ops(problem.C,'norm');%norm(C)

problem.Z0 = TEBD_ops(problem.C,'zeros');
problem.y0 = zeros(size(problem.b));
