%Test the SDP relaxation of Binary Integer Quadratic Problems (BIQs)
%%
%% Solves various SDP relaxation of BIQs using 2EBD-HPE. 
%% The problems are solved defining the problems as two-easy-block 
%% structured convex optimization problems of the form:
%%
%%                              min f(x)+h_1(x)+h_2(x)
%%
%% results = TEBD_test_BIQ
%%
%% [1] R. D.C Monteiro, C. Ortiz and B. F. Svaiter. A first-order
%%     block-decomposition method for solving two-easy-block structured
%%     semidefinite programs, 2012.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013
function results = TEBD_test_BIQ(varargin)

[TEBD,params] = TEBD_GetAlgorithm(varargin);
fprintf('\nTest using Matlab 2EBD-HPE function: %s\n\n',func2str(TEBD));

biqinstances = {
%                 'be100.1.sparse'
%                 'be100.10.sparse'
%                 'be100.2.sparse'
%                 'be100.3.sparse'
%                 'be100.4.sparse'
%                 'be100.5.sparse'
%                 'be100.6.sparse'
%                 'be100.7.sparse'
%                 'be100.8.sparse'
                'be100.9.sparse'
%                 'be120.3.1.sparse'
%                 'be120.3.10.sparse'
%                 'be120.3.2.sparse'
%                 'be120.3.3.sparse'
%                 'be120.3.4.sparse'
%                 'be120.3.5.sparse'
%                 'be120.3.6.sparse'
%                 'be120.3.7.sparse'
%                 'be120.3.8.sparse'
%                 'be120.3.9.sparse'
%                 'be120.8.1.sparse'
%                 'be120.8.10.sparse'
%                 'be120.8.2.sparse'
%                 'be120.8.3.sparse'
%                 'be120.8.4.sparse'
%                 'be120.8.5.sparse'
%                 'be120.8.6.sparse'
%                 'be120.8.7.sparse'
%                 'be120.8.8.sparse'
%                 'be120.8.9.sparse'
%                 'be150.3.1.sparse'
%                 'be150.3.10.sparse'
%                 'be150.3.2.sparse'
%                 'be150.3.3.sparse'
%                 'be150.3.4.sparse'
%                 'be150.3.5.sparse'
%                 
%                 'be150.3.7.sparse'
%                 'be150.3.8.sparse'
%                 'be150.3.9.sparse'
%                 'be150.8.1.sparse'
%                 'be150.8.10.sparse'
%                 'be150.8.2.sparse'
%                 'be150.8.3.sparse'
%                 'be150.8.4.sparse'
%                 'be150.8.5.sparse'
%                 'be150.8.6.sparse'
%                 'be150.8.7.sparse'
%                 'be150.8.8.sparse'
%                 'be150.8.9.sparse'
%                 'be200.3.1.sparse'
%                 'be200.3.10.sparse'
%                 'be200.3.2.sparse'
%                 'be200.3.3.sparse'
%                 'be200.3.4.sparse'
%                 'be200.3.5.sparse'
%                 'be200.3.6.sparse'
%                 'be200.3.7.sparse'
%                 'be200.3.8.sparse'
%                 'be200.3.9.sparse'
%                 'be200.8.1.sparse'
%                 'be200.8.10.sparse'
%                 'be200.8.2.sparse'
%                 'be200.8.3.sparse'
%                 'be200.8.4.sparse'
%                 'be200.8.5.sparse'
%                 'be200.8.6.sparse'
%                 'be200.8.7.sparse'
%                 'be200.8.8.sparse'
%                 'be200.8.9.sparse'
%                 'be250.1.sparse'
%                 'be250.10.sparse'
%                 'be250.2.sparse'
%                 'be250.3.sparse'
%                 'be250.4.sparse'
%                 'be250.5.sparse'
%                 'be250.6.sparse'
%                 'be250.7.sparse'
%                 'be250.8.sparse'
%                 'be250.9.sparse'
%                 'bqp100-1.sparse'
%                 'bqp100-10.sparse'
%                 'bqp100-2.sparse'
%                 'bqp100-3.sparse'
%                 'bqp100-4.sparse'
                'bqp100-5.sparse'
%                 'bqp100-6.sparse'
%                 'bqp100-7.sparse'
%                 'bqp100-8.sparse'
%                 'bqp100-9.sparse'
%                 'bqp250-1.sparse'
%                 'bqp250-10.sparse'
%                 'bqp250-2.sparse'
%                 'bqp250-3.sparse'
%                 'bqp250-4.sparse'
%                 'bqp250-5.sparse'
%                 'bqp250-6.sparse'
%                 'bqp250-7.sparse'
%                 'bqp250-8.sparse'
%                 'bqp250-9.sparse'
%                 'bqp500-1.sparse'
%                 'bqp500-10.sparse'
%                 'bqp500-2.sparse'
%                 'bqp500-3.sparse'
%                 'bqp500-4.sparse'
%                 'bqp500-5.sparse'
%                 'bqp500-6.sparse'
%                 'bqp500-7.sparse'
%                 'bqp500-8.sparse'
%                 'bqp500-9.sparse'
%                 'gka10b.sparse'
%                 'gka10d.sparse'
%                 'gka1d.sparse'
%                 'gka1e.sparse'
%                 'gka1f.sparse'
%                 'gka2d.sparse'
%                 'gka2e.sparse'
%                 'gka2f.sparse'
%                 'gka3d.sparse'
%                 'gka3e.sparse'
%                 'gka3f.sparse'
                'gka4d.sparse'
%                 'gka4e.sparse'
%                 'gka4f.sparse'
%                 'gka5d.sparse'
%                 'gka5e.sparse'
%                 'gka5f.sparse'
%                 'gka6d.sparse'
%                 'gka7c.sparse'
%                 'gka7d.sparse'
%                 'gka8a.sparse'
%                 'gka8d.sparse'
%                 'gka9b.sparse'
%                 'gka9d.sparse'               
			};

maxprobs = length(biqinstances);
results = cell(1,maxprobs);
for prob = 1:maxprobs;
    clear problem
    
    problem.file = biqinstances{prob};
    params = TEBD_GetParams_BIQ(params);
    [problem,params] = TEBD_GetProblem_BIQ(problem,params);
   
    results{prob} = TEBD(params,problem);
     
    pause(1);
end
end

