%Test the \theta-function SDP relaxation for the maximum stable set problem
%%
%% Solves various \theta-function SDPs using 2EBD-HPE. 
%% The problems are solved defining the problems as two-easy-block 
%% structured convex optimization problems of the form:
%%
%%                              min f(x)+h_1(x)+h_2(x)
%%
%% results = TEBD_test_THETA
%%
%% [1] R. D.C Monteiro, C. Ortiz and B. F. Svaiter. A first-order
%%     block-decomposition method for solving two-easy-block structured
%%     semidefinite programs, 2012.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013
function results = TEBD_test_THETA(varargin)

[TEBD,params] = TEBD_GetAlgorithm(varargin);
fprintf('\nTest using Matlab 2EBD-HPE function: %s\n\n',func2str(TEBD));

thetainstances = {
%     '1dc.1024.dat-s'
%     '1dc.512.dat-s'
%     '1et.1024.dat-s'
%     '1et.512.dat-s'
%     '1tc.1024.dat-s'
%     '1tc.512.dat-s'
%     '1zc.1024.dat-s'
%     '1zc.512.dat-s'
%     '2dc.1024.dat-s'
%     '2dc.512.dat-s'
%     'G43.mat'
%     'G44.mat'
%     'G45.mat'
%     'G46.mat'
%     'G47.mat'
%     'G51.mat'
%     'G52.mat'
%     'G53.mat'
%     'G54.mat'
%     'hamming-10-2.mat'
    'hamming-9-5-6.mat'
%     'hamming-9-8.mat'
%     'theta12.dat-s'
%     'theta123.dat-s'       
    };

maxprobs = length(thetainstances);
results = cell(1,maxprobs);
for prob = 1:maxprobs;
    clear problem
    
    problem.file = thetainstances{prob};
    params = TEBD_GetParams_THETA(params);
    [problem,params] = TEBD_GetProblem_THETA(problem,params);
    
    results{prob} = TEBD(params,problem);
    
    pause(1);
end
end

