%Test the SDP instance from various applications. With aggresive choice of
%parameters (more likely to diverge if the problem is difficult).
%%
%% Solves random ell_1 min problem of the form 
%%                 min\|x\|_1  s.t Ax=b. or \|Ax-b\|_2<=epsilon.
%% The problems are solved defining the problems as two-easy-block
%% structured convex optimization problems of the form:
%%
%%                              min f(x)+h_1(x)+h_2(x)
%%
%% results = TEBD_test_SDPs
%%
%% [1] R. D.C Monteiro, C. Ortiz and B. F. Svaiter. A first-order
%%     block-decomposition method for solving two-easy-block structured
%%     semidefinite programs, 2012.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 2EBD-HPE:
%% Modified by C.Ortiz
%% Last Modified: 5/31/2013
function results = TEBD_test_ell_1(varargin)

[TEBD,params] = TEBD_GetAlgorithm(varargin);
fprintf('\nTest using Matlab 2EBD-HPE function: %s\n\n',func2str(TEBD));

ell_1_instances = {
    '1280 500 140 1280500140' 'RAND_ell_1_exact';
    '1280 500 140 1280500140 0.01' 'RAND_ell_1_inexact';
    };

maxprobs = size(ell_1_instances,1);
results = cell(1,maxprobs);
for prob = 1:maxprobs;
    clear problem
    
    problem.file = ell_1_instances{prob,1};
    problem.format = ell_1_instances{prob,2};
    params = TEBD_GetParams_ell_1(params);
    problem = TEBD_Get_RAND_ell_1(problem);
    [problem,params] = TEBD_GetProblem_ell_1(problem,params);
    
    results{prob} = TEBD(params,problem);
    
    pause(1);
    fprintf('\n\n\n');
end
end

